@@ -10,8 +10,8 @@
 #define XTENSOR_CONFIG_HPP
 
 #define XTENSOR_VERSION_MAJOR 0
-#define XTENSOR_VERSION_MINOR 17
-#define XTENSOR_VERSION_PATCH 4
+#define XTENSOR_VERSION_MINOR 18
+#define XTENSOR_VERSION_PATCH 0
 
 // DETECT 3.6 <= clang < 3.8 for compiler bug workaround.
 #ifdef __clang__
@@ -25,7 +25,10 @@
 // Workaround for some missing constexpr functionality in MSVC 2015 and MSVC 2017 x86
 #if defined(_MSC_VER)
     #define XTENSOR_CONSTEXPR_ENHANCED const
-    #define XTENSOR_CONSTEXPR_ENHANCED_STATIC const
+    // The following must not be defined to const, otherwise
+    // it prevents generation of copy operators of classes
+    // containing XTENSOR_CONSTEXPR_ENHANCED_STATIC members
+    #define XTENSOR_CONSTEXPR_ENHANCED_STATIC
     #define XTENSOR_CONSTEXPR_RETURN inline
 #else
     #define XTENSOR_CONSTEXPR_ENHANCED constexpr
